tuplettools.make_tuplet_from_duration_and_ratio
===============================================

.. autofunction:: abjad.tools.tuplettools.make_tuplet_from_duration_and_ratio.make_tuplet_from_duration_and_ratio
   :noindex:
